@@ -1,5 +1,8 @@
 package org.gcube.portlets.user.td.tablewidget.client.rows;
 
+import org.gcube.portal.clientcontext.client.GCubeClientContext;
+import org.gcube.portlets.user.td.gwtservice.shared.Constants;
+
 import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.http.client.Request;
@@ -10,16 +13,22 @@ import com.google.gwt.http.client.Response;
 
 /**
  * 
- * @author giancarlo
- * email: <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
+ * @author giancarlo email: <a
+ *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
  *
  */
 public class RowsDataClient {
-	public void retrievesRowsAsJson()  {
+	private static final String TDWXROWSDATA = "tdwxrowsdata";
+
+	public void retrievesRowsAsJson() {
 		// Send request to server and catch any errors.
-		String path = GWT.getModuleBaseURL() + "tdwxrowsdata";
+		String path = GWT.getModuleBaseURL() + TDWXROWSDATA + "?"
+				+ Constants.CURR_GROUP_ID + "="
+				+ GCubeClientContext.getCurrentContextId();
 		RequestBuilder builder = new RequestBuilder(RequestBuilder.POST, path);
-		
+		builder.setHeader(Constants.CURR_GROUP_ID,
+				GCubeClientContext.getCurrentContextId());
+
 		try {
 			Request request = builder.sendRequest(null, new RequestCallback() {
 				public void onError(Request request, Throwable exception) {
@@ -32,7 +41,7 @@ public class RowsDataClient {
 					}
 				}
 			});
-			Log.debug("Request: "+request.toString());
+			Log.debug("Request: " + request.toString());
 		} catch (RequestException e) {
 			e.printStackTrace();
 		}
